pub enum Decision {
DraftInternalCandidate,
StaffReviewRequired {
reason: ReviewReason,
gate: ReviewGate,
},
ManagerReviewRequired {
reason: ReviewReason,
gate: ReviewGate,
},
Suppressed {
reason: SuppressionReason,
},
}Expand description
Recommendation decision that either drafts an internal candidate, requires review, or suppresses the upsell.
Variants
DraftInternalCandidate
Draft internal candidate retail operational signal for inventory, POS, reorder, recommendation, or review handling.
StaffReviewRequired
Staff review required retail operational signal for inventory, POS, reorder, recommendation, or review handling.
Fields
reason: ReviewReasonBusiness reason staff should review before proceeding.
gate: ReviewGateSource-derived gate carried by this retail contract.
ManagerReviewRequired
Manager review required retail operational signal for inventory, POS, reorder, recommendation, or review handling.
Fields
reason: ReviewReasonBusiness reason staff should review before proceeding.
gate: ReviewGateSource-derived gate carried by this retail contract.
Suppressed
Suppressed retail operational signal for inventory, POS, reorder, recommendation, or review handling.
Fields
reason: SuppressionReasonBusiness reason staff should review before proceeding.